# Body
[![pypi version](https://img.shields.io/pypi/v/body-oc.svg)](https://pypi.org/project/body-oc) ![MIT License](https://img.shields.io/pypi/l/body-oc.svg)

API and shared functionality for all body parts (services) created by Ouroboros
Coding Inc.

This code comes without documentation as it's not meant to be used by anyone
outside of Ouroboros Coding Inc. The code itself is highly commented and
documented however, and can easily be followed.

Please see [LICENSE](LICENSE) for further information.